@@ -29,14 +29,14 @@ class Compiler(object):
                 compiler = compiler(self.verbose)
                 if compiler.match_file(path):
                     new_path = self.output_path(path, compiler.output_extension)
-                    content = self.read_file(path)
+                    paths[index] = new_path
                     try:
+                        content = self.read_file(path)
                         compiled_content = compiler.compile_file(content, finders.find(path))
                         self.save_file(new_path, compiled_content)
                     except CompilerError:
                         if not self.storage.exists(new_path) or not settings.PIPELINE:
                             raise
-                    paths[index] = new_path
         return paths
 
     def output_path(self, path, extension):
@@ -49,6 +49,12 @@ class Compiler(object):
         file.close()
         return content
 
+    def is_outdated(self, path, new_path):
+        try:
+            return self.storage.modified_time(path) > self.storage.modified_time(new_path)
+        except OSError:
+            return True
+
     def save_file(self, path, content):
         return self.storage.save(path, ContentFile(smart_str(content)))
 
